Pa = 7 # Tanalog = 10**-Pa
#Ta = 10**(-Pa)

Nmax = 1e6 # nombre d'échantillons max dans un signal

liste_xmin_xmax = [0., 1e-4]
Xe = 10**-Pa



F = 1e5
Vpp = 2
type_signal = "cosinus"

liste_an = [0., Vpp/2]
liste_bn = []
liste_umin_umax = [-10, 10]
Pbits = 16

calibre = 10.
repetition = True


